from setuptools import find_packages, setup

with open("README.rst", "r") as fh:
    long_description = fh.read()

setup(
    name="odoo_scripts",
    description="Collection of scripts for Odoo",
    version="15.1.0",
    long_description=long_description,
    long_description_content_type="text/x-rst",
    author="XCG Consulting",
    license="MIT",
    packages=find_packages(),
    install_requires=[
        "odoorpc>=0.8.0",
        "requests_toolbelt==0.8.0",
        "python-dateutil>=2.7.0",
        "coloredlogs",
        "PyYAML",
    ],
    extras_require={
        # used to require PyYAML but it is used in import scripts too
        "conf2reST": [],
        "docker": ["docker >=3.4", "dockerpty"],
        "import_sql": ["psycopg2"],
        "source_control": [
            # Only mercurial 5.2 support Python 3.5+
            "mercurial >=5.2",
            "python-hglib",
        ],
    },
    entry_points={
        "console_scripts": [
            "import_base_import=odoo_scripts.import_base_import:main",
            "import_jsonrpc=odoo_scripts.import_jsonrpc:main",
            "import_sql=odoo_scripts.import_sql:main [import_sql]",
            "docker_dev_start=odoo_scripts.docker_dev_start:main [docker]",
            "do_tests=odoo_scripts.do_tests:main",
            "docker_build=odoo_scripts.docker_build:main [docker]",
            "docker_build_clean=odoo_scripts.docker_build_clean:main",
            "docker_build_copy=odoo_scripts.docker_build_copy:main",
            "docker_flake8=odoo_scripts.docker_flake8:main [docker]",
            "docker_isort=odoo_scripts.docker_isort:main [docker]",
            "docker_pg=odoo_scripts.docker_postgresql:main [docker]",
            "docker_pylint=odoo_scripts.docker_pylint:main [docker]",
            "conf2reST=odoo_scripts.conf2reST:main [conf2reST]",
            "list_modules=odoo_scripts.list_modules:main",
            "update_duplicate_sources="
            "odoo_scripts.update_duplicate_sources:main [source_control]",
        ]
    },
    scripts=[],
    python_requires=">=3.6",
    url="https://orus.io/xcg/odoo_scripts/",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Environment :: Console",
    ],
)
